@@ -88,6 +88,8 @@ class BatchProcessor:
             module_glob = os.path.join(module_root_dir, "**/*.py")
             files=glob.glob(module_glob, recursive = True)
             for module_filepath in files:
+                if module_filepath.startswith("__"):
+                    continue
                 if fk.utils.file_contains_str(module_filepath, self.entry_name):
                     try:
                         module, failure = self.load_module_by_filepath(module_filepath, module_filepath)
